==> hinemos-2.1.0_src.tar.gz: hinemos-2.1.0_src/JobManagementCore/src/com/clustercontrol/jobmanagement/action/GetRunScheduleDetailList.java <==
/*
 
Copyright (C) 2006 NTT DATA Corporation
 
This program is free software; you can redistribute it and/or
Modify it under the terms of the GNU General Public License 
as published by the Free Software Foundation, version 2.
 
This program is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied 
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
PURPOSE.  See the GNU General Public License for more details.
 
*/

package com.clustercontrol.jobmanagement.action;

import java.rmi.AccessException;
import java.rmi.RemoteException;

import javax.ejb.FinderException;
import javax.naming.NamingException;

import org.eclipse.jface.dialogs.MessageDialog;
import org.quartz.SchedulerException;

import com.clustercontrol.bean.CommonTableTreeItem;
import com.clustercontrol.jobmanagement.ejb.session.JobController;
import com.clustercontrol.jobmanagement.util.EjbConnectionManager;
import com.clustercontrol.util.Messages;

/**
 * ͽٰܺ饹
 * 
 * Фͽٰܺ
 * 
 * @version 2.0.0
 * @since 2.0.0
 */
public class GetRunScheduleDetailList {

	/**
	 * ͽٰܺ
	 * 
	 * @return ͽٰܺ
	 */
	public CommonTableTreeItem get(String scheduleId) {
		JobController job = 
			EjbConnectionManager.getConnectionManager().getJobController();
		
		CommonTableTreeItem item = null;
        try {
        	item = job.getRunScheduleDetailList(scheduleId);
        } catch (RemoteException e) {
			if(e instanceof AccessException){
				// ʤξ硢顼ɽ
	            MessageDialog.openInformation(null, Messages.getString("message"),
	                    Messages.getString("message.accesscontrol.16"));
			}
        } catch (NamingException e) {
        } catch (FinderException e) {
		} catch (SchedulerException e) {
		}
		return item;
	}
}

==> hinemos-2.1.1_src.tar.gz: hinemos-2.1.1_src/JobManagementCore/src/com/clustercontrol/jobmanagement/action/GetRunScheduleDetailList.java <==
/*
 
Copyright (C) 2006 NTT DATA Corporation
 
This program is free software; you can redistribute it and/or
Modify it under the terms of the GNU General Public License 
as published by the Free Software Foundation, version 2.
 
This program is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied 
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
PURPOSE.  See the GNU General Public License for more details.
 
*/

package com.clustercontrol.jobmanagement.action;

import java.rmi.AccessException;
import java.rmi.RemoteException;

import javax.ejb.FinderException;
import javax.naming.NamingException;

import org.eclipse.jface.dialogs.MessageDialog;
import org.quartz.SchedulerException;

import com.clustercontrol.bean.CommonTableTreeItem;
import com.clustercontrol.jobmanagement.ejb.session.JobController;
import com.clustercontrol.jobmanagement.util.EjbConnectionManager;
import com.clustercontrol.util.Messages;

/**
 * ジョブ[実行予定詳細]ビューの左側の実行予定詳細一覧情報を取得するクラスです。
 * 
 * マネージャにSessionBean経由でアクセスし、実行予定詳細一覧情報を取得する
 * 
 * @version 2.0.0
 * @since 2.0.0
 */
public class GetRunScheduleDetailList {
	
	/**
	 * マネージャにSessionBean経由でアクセスし、<BR>
	 * 実行予定詳細一覧情報を取得する
	 * 
	 * @param scheduleId スケジュールID
	 * @return 実行予定詳細一覧情報（Objectの2次元配列）
	 * 
	 * @see com.clustercontrol.jobmanagement.ejb.session.JobController
	 * @see com.clustercontrol.jobmanagement.util.EjbConnectionManager
	 * @see com.clustercontrol.jobmanagement.ejb.session.JobControllerBean#getRunScheduleDetailList(java.lang.String)
	 */
	public CommonTableTreeItem get(String scheduleId) {
		JobController job = 
			EjbConnectionManager.getConnectionManager().getJobController();
		
		CommonTableTreeItem item = null;
		try {
			item = job.getRunScheduleDetailList(scheduleId);
		} catch (RemoteException e) {
			if(e instanceof AccessException){
				// アクセス権なしの場合、エラーダイアログを表示する
				MessageDialog.openInformation(null, Messages.getString("message"),
						Messages.getString("message.accesscontrol.16"));
			}
		} catch (NamingException e) {
		} catch (FinderException e) {
		} catch (SchedulerException e) {
		}
		return item;
	}
}
